﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Text;
using System.Windows.Forms;
using SimioAPI;
using SimioAPI.Extensions;

namespace ImportExperiment
{
    public class ImportExperimentAddIn : IDesignAddIn //, IDesignAddInGuiDetails
    {
        #region IDesignAddIn Members

        /// <summary>
        /// Property returning the name of the add-in. This name may contain any characters and is used as the display name for the add-in in the UI.
        /// </summary>
        public string Name
        {
            get { return "Import Experiment"; }
        }

        /// <summary>
        /// Property returning a short description of what the add-in does.  
        /// </summary>
        public string Description
        {
            get { return "Import experiment from csv file."; }
        }

        /// <summary>
        /// Property returning an icon to display for the add-in in the UI.
        /// </summary>
        public System.Drawing.Image Icon
        {
            get { return Properties.Resources.Icon; }
        }

        /// <summary>
        /// Method called when the add-in is run.
        /// </summary>
        public void Execute(SimioAPI.Extensions.IDesignContext context)
        {
            IExperiment experiment;
            if (context.ActiveExperiment != null)
            {
                experiment = context.ActiveExperiment;
            }
            else if (context.ActiveModel != null)
            {
                experiment = context.ActiveModel.Experiments.Create();
                experiment.Scenarios.Clear();
            }
            else
            {
                MessageBox.Show("You must have an active model to run this add-in.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            String FileName;
            OpenFileDialog dlg = new OpenFileDialog();
            dlg.Filter = "Comma Separated Value Files (*.csv)|*.csv";
            dlg.Title = "Select File to Import";
            if (dlg.ShowDialog() == DialogResult.OK)
            {
                FileName = dlg.FileName;
            }
            else
            {
                return;
            }
            IScenarios scenarios = experiment.Scenarios;
            IExperimentControls controls = experiment.Controls;
            // Read control values from input file and create scenarios
            using (TextReader reader = File.OpenText(FileName))
            {
                String line;
                while ((line = reader.ReadLine()) != null)
                {
                    int controlIndex = 0;
                    IScenario scenario = scenarios.Create();
                    String[] values = line.Split(',');
                    if (values.Length != controls.Count)
                    {
                        MessageBox.Show("The number of controls in the input file does not match that of your experiment.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        return;
                    }
                    foreach (var control in controls)
                    {
                        scenario.SetControlValue(control, values[controlIndex++]);
                    }
                }
            }
        }

        #endregion

        #region IDesignAddInGuiDetails Members

        // Here is a sample implementation of the optional IDesignAddInGuiDetails interface.
        // To use this implementation, un-comment the interface name on the "class" line at
        // the top of this file.
        //
        // If a design-time add-in implements this optional interface, it can specify where
        // in Simio's ribbon area it should appear.  Merely implementing the interface, and
        // returning null for CategoryName, TabName, and GroupName will cause the add-in to
        // appear at a default location defined by Simio.  However, the add-in can return a
        // specific name for any or all of these properties, to indicate where it should be
        // located in Simio's ribbon area.

        /// <summary>
        /// Property returning the category name for this Add-In.  Return null to use Simio's default add-in category name.
        /// </summary>
        public string CategoryName
        {
            get { return null; }
        }

        /// <summary>
        /// Property returning the group name for this Add-In.  Return null to use Simio's default add-in group name.
        /// </summary>
        public string GroupName
        {
            get { return null; }
        }

        /// <summary>
        /// Property returning the tab name for this Add-In.  Return null to use Simio's default add-in tab name.
        /// </summary>
        public string TabName
        {
            get { return null; }
        }

        #endregion
    }
}
